@@ -1,4 +1,6 @@
 import os.path
+
+import allure
 import cjen
 from cjen import BigTangerine
 
@@ -10,7 +12,9 @@ class MockService(BigTangerine):
     @cjen.headers.contentType(value="application/json")
     @cjen.http.post_mapping(uri="post_method_json")
     def post_method_json(self, *, data, resp=None, **kwargs):
-        assert resp.get("procCode") == 200
+        with allure.step("tttt"):
+            print(resp)
+            assert resp.get("procCode") == 200
 
     @cjen.http.post_mapping(uri="post_method_variable/{id}")
     def post_method_variable(self, *, path_variable: dict, resp=None, **kwargs):
@@ -69,12 +73,24 @@ class MockService(BigTangerine):
             assert f.read() == "TestUploadFile"
         os.remove(path)
 
+    @cjen.http.upload_mapping(uri="upload_file/{id}")
+    def upload_file1(self, path_variable, data, resp=None, **kwargs):
+        assert resp.get("procCode") == 200
+        path = os.path.join(os.path.dirname(__file__), "upload_target.txt")
+        with open(path, "r") as f:
+            assert f.read() == "TestUploadFile"
+        os.remove(path)
 
+
+@allure.feature("测试POST请求")
 def test_post():
     mock = MockService()
-    mock.post_method_json(data=dict(username="xx", pwd="yyy"))
-    mock.post_method_variable(path_variable=dict(id=1))
-    mock.post_method_path_variable(path_variable=dict(id=1))
+    with allure.step("测试Post请求: 参数为Json"):
+        mock.post_method_json(data=dict(username="xx", pwd="yyy"))
+    with allure.step("测试Post请求: 参数在URL"):
+        mock.post_method_variable(path_variable=dict(id=1))
+    with allure.step("测试Post请求: 参数在URL1"):
+        mock.post_method_path_variable(path_variable=dict(id=1))
 
 
 def test_download():
@@ -92,6 +108,10 @@ def test_upload():
     mock = MockService()
     mock.upload_file(data=dict(file=os.path.join(os.path.dirname(__file__), "upload_source.txt")))
 
+def test_upload1():
+    mock = MockService()
+    mock.upload_file1(path_variable = dict(id = 1),data=dict(file=os.path.join(os.path.dirname(__file__), "upload_source.txt")))
+
 
 def test_put():
     mock = MockService()
@@ -105,3 +125,5 @@ def test_delete():
     mock.delete_method_json(data=dict(username="xx", pwd="yyy"))
     mock.delete_method_variable(path_variable=dict(id=1))
     mock.delete_method_path_variable(path_variable=dict(id=1))
+
+
