@@ -11,7 +11,7 @@ class StepMockService(BigTangerine):
         super().__init__()
 
     @cjen.headers.contentType(value="application/json")
-    @cjen.http.post_mapping(uri="post_method_json",json_clazz=OKResponse)
+    @cjen.http.post_mapping(uri="post_method_json", json_clazz=OKResponse)
     @cjen.step.call(stepName=OkStep.Name, argName="ok")
     @cjen.step.call(stepName=OtherStep.Name, argName="ok")
     def post_method_json(self, *, data, ok: OKResponse = None, resp=None, **kwargs): ...
@@ -23,7 +23,17 @@ def test_one_step():
     OkStep(mock, None).run()
     # mock.post_method_json(data=dict(username="xx", pwd="yyy"))
 
+
 def test_two_step():
     mock = StepMockService()
     OkStep(mock, None).run()
     OtherStep(mock, None).run()
+
+
+# 验证在没有执行之前，Step 是不会注册进入Service的
+def test_register():
+    mock = StepMockService()
+    steps = [OkStep(mock, None), OtherStep(mock, None)]
+    for i, step in enumerate(steps):
+        step.run()
+        assert len(mock.step_definitions) == i + 1
